@@ -43,7 +43,7 @@ has options => (
 sub _build_plugins {
     my ( $self ) = @_;
     return [
-        'GatherDir',                    # REQUIRE: Dist::Zilla::Plugin::GatherDir
+        'GatherDir',                    ## REQUIRE: Dist::Zilla::Plugin::GatherDir
         [ $Plugin => $self->options ],
     ];
 };
